#!/bin/ksh
# *****************************************************************************
#  Patch #4 for Service Profiler v1.1
# *****************************************************************************
#  Wrightia, S.A. (c) 2009
#
#  Purpose:
#     Update support for LINUX to the Service Profiler v1.1.
#
#  Input parameters:
#     $1          : IS_DIR (The Integration Server installation directory)
#
#  Results:
#     1. Copies new versions of the LINUX native libraries into the Service
#			Profiler installed run directory structure.
#
#  Exit codes:
#     0  - OK
#
# *****************************************************************************

log() {
   echo "[$1] [`date +%C%y-%m-%d\ %H:%M:%S`] $2" >> updates.log
}

logError() {
   log "ERROR" "$1"
}

logWarning() {
   log "WARNING" "$1"
}

logInfo() {
   log "INFO" "$1"
}

#--< MAIN	>------------------------------------------------------------------
if [ -d ../error ]; then
   if [ ! -z "`ls ../error/ | sort | grep .upd.sh`" ] ; then
      logWarning "Previous updates with error were found: '$0 $*' skipped."
      exit 100
   fi
else
   mkdir ../error
fi

xISHome=$1
xTargetHome=$xISHome/serviceprofiler
if [ -d "$xTargetHome" ] ; then
   # update (or create) LINUX native libraries
   cp ../../serviceprofiler/lib/liblnx* "$xTargetHome/lib/"
   xEL=$?
   if [ $xEL -eq 0 ]; then
      logInfo "LINUX dynamic libraries copied successfully."
   else
      logError "Error '$xEL' copying libraries."
      exit $xEL
   fi
else
   logWarning "Directory '$xISHome/serviceprofiler' was not found: '$0 $*' not applied."
fi

